@@ -91,8 +91,15 @@ void winetricks::run_winetricks(QString item){
         sh_args.append("env");
 
         if (!proxy_host.isEmpty()){
-            sh_args.append(QString("HTTP_PROXY=http://%1:%2").arg(proxy_host).arg(CoreLib->getSetting("network", "port", false).toString()));
-            sh_args.append(QString("FTP_PROXY=http://%1:%2").arg(proxy_host).arg(CoreLib->getSetting("network", "port", false).toString()));
+            QString proxy_auth = CoreLib->getSetting("network", "user", false).toString();
+            if (!proxy_auth.isEmpty()){
+                QString proxy_pass = CoreLib->getSetting("network", "pass", false).toString();
+                proxy_auth.append(QString(":%1@").arg(proxy_pass));
+            }
+            QString proxy_var = QString("http://%1%2:%3").arg(proxy_auth).arg(proxy_host).arg(CoreLib->getSetting("network", "port", false).toString());
+            sh_args.append(QString("http_proxy='%1'").arg(proxy_var));
+            sh_args.append(QString("https_proxy='%1'").arg(proxy_var));
+            sh_args.append(QString("ftp_proxy='%1'").arg(proxy_var));
         }
 
         QHash<QString, QString> prefix_info = db_prefix.getByName(this->prefix_name);
@@ -154,14 +161,30 @@ void winetricks::run_winetricks(QString item){
 }
 
 void winetricks::downloadwinetricks () {
-        /*
-         * Downloading winetricks and installing it
-         */
+    /*
+     * Downloading winetricks and installing it
+     */
     this->winetricks_bin = QDir::homePath();
     this->winetricks_bin.append("/.config/");
     this->winetricks_bin.append(APP_SHORT_NAME);
     this->winetricks_bin.append("/winetricks");
 
+    QFile file(this->winetricks_bin);
+
+    if (file.exists()){
+        if (!file.open(QIODevice::ReadWrite | QIODevice::Text)){
+            QMessageBox::warning(this, QString(tr("Error")), QString(tr("File '%1' is not writable or not readable. Check file permissions.").arg(this->winetricks_bin)));
+            return;
+        }
+    } else {
+        if (!file.open(QIODevice::ReadWrite | QIODevice::Text)){
+            QMessageBox::warning(this, QString(tr("Error")), QString(tr("Can't create file '%1'. Check folder permissions.").arg(this->winetricks_bin)));
+            return;
+        } else {
+            file.remove();
+        }
+    }
+
     QStringList args;
     if (!console_args.isEmpty()){
         // If we have any conslope parametres, we gona preccess them one by one
@@ -172,18 +195,25 @@ void winetricks::downloadwinetricks () {
         }
     }
 
-    QString proxy_host = CoreLib->getSetting("network", "host", false).toString();
-    if (!proxy_host.isEmpty()){
-        args.append("env");
-        args.append(QString("HTTP_PROXY=http://%1:%2").arg(proxy_host).arg(CoreLib->getSetting("network", "port", false).toString()));
-        args.append(QString("FTP_PROXY=http://%1:%2").arg(proxy_host).arg(CoreLib->getSetting("network", "port", false).toString()));
-    }
-
     QString arg;
     arg.append(CoreLib->getWhichOut("sh"));
     arg.append(" -c \"");
+
+    if (CoreLib->getSetting("network", "type", 0).toInt() != 0){
+        QString proxy_host = CoreLib->getSetting("network", "host", false).toString();
+        if (!proxy_host.isEmpty()){
+            QString proxy_auth = CoreLib->getSetting("network", "user", false).toString();
+            if (!proxy_auth.isEmpty()){
+                QString proxy_pass = CoreLib->getSetting("network", "pass", false).toString();
+                proxy_auth.append(QString(":%1@").arg(proxy_pass));
+            }
+            QString proxy_var = QString("http://%1%2:%3").arg(proxy_auth).arg(proxy_host).arg(CoreLib->getSetting("network", "port", false).toString());
+            arg.append(QString("env https_proxy='%1' ").arg(proxy_var));
+        }
+    }
+
     arg.append(CoreLib->getWhichOut("wget"));
-    arg.append(" http://kegel.com/wine/winetricks -O ");
+    arg.append(" https://raw.githubusercontent.com/Winetricks/winetricks/master/src/winetricks -O ");
     arg.append(this->winetricks_bin);
     arg.append(" && ");
     arg.append(CoreLib->getWhichOut("chmod"));
@@ -216,6 +246,7 @@ QStringList winetricks::get_stdout_lines(QString command){
 
     p.start(command);
     p.waitForFinished();
+
     QString stdout = codec->toUnicode(p.readAllStandardOutput());
     return stdout.split("\n");
 }
@@ -224,9 +255,11 @@ bool winetricks::parse() {
     if (!check_script())
         return false;
 
-    QProgressDialog *pd = new QProgressDialog(tr("Refreshing winetricks application list."), QString(), 0, 100);
+    QProgressDialog *pd = new QProgressDialog(tr("Refreshing Winetricks application list."), QString(), 0, 100);
     pd->setModal(true);
-    pd->show();
+    pd->setWindowTitle(tr("Winetricks plugin"));
+    pd->setFixedWidth(400);
+    pd->show();  
     pd->setValue(5);
     QCoreApplication::processEvents(QEventLoop::WaitForMoreEvents, 100);
 
@@ -253,8 +286,10 @@ bool winetricks::parse() {
 
     foreach (QString subtype, subtypes){
         pd->setValue(pd->value() + step);
+        pd->setLabelText(tr("Reading category: %1").arg(subtype));
         QCoreApplication::processEvents(QEventLoop::WaitForMoreEvents, 100);
-        if (!subtype.isEmpty()){
+        if ((!subtype.isEmpty()) and (!subtype.startsWith("Using winetricks"))) {
+            qDebug() << "\"" << subtype << "\"";
             subtype = subtype.trimmed();
             pargs.clear();
             pargs.append(winetricks_bin);
@@ -262,9 +297,9 @@ bool winetricks::parse() {
             pargs.append(subtype);
             pargs.append(" list");
             foreach (QString item, this->get_stdout_lines(pargs)){
-                if (item.isEmpty())
+                if ((item.isEmpty()) or (item.startsWith("Using winetricks")))
                     continue;
-                db_sysconfig.add_item(item.left(24).trimmed(), "application-x-ms-dos-executable", item.mid(24).trimmed(), subtype, D_PROVIDER_WINETRICKS);
+                db_sysconfig.add_item(item.section(' ', 0, 0), "application-x-ms-dos-executable", item.section(' ', 1, -1, QString::SectionSkipEmpty), subtype, D_PROVIDER_WINETRICKS);
             }
         }
     }
