@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2013 by Alexey S. Malakhov <brezerk@gmail.com>     *
+ *   Copyright (C) 2008-2016 by Alexey S. Malakhov <brezerk@gmail.com>     *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -54,7 +54,7 @@ class Run : public QDialog, public Ui::Run
          *
          * \param  prefix_name  Current user selected prefix name.
          */
-        Run(QWidget * parent = 0, Qt::WFlags f = 0);
+        Run(QWidget * parent = 0, Qt::WindowFlags f = 0);
         void prepare(QString prefix_name, QString wrkdir="", QString override="", QString winedebug="", QString useconsole="", QString display="", QString cmdargs="", QString desktop="", int nice = 0, QString exec = "", QString lang = "");
         ExecObject execObj;
     private slots:
@@ -68,8 +68,6 @@ class Run : public QDialog, public Ui::Run
         void comboPrefixes_indexChanged (int);
         //! \brief CheckBox change slot.
         void cbUseConsole_stateChanged(int);
-        //! \brief Resize window content slot.
-        void ResizeContent(int TabIndex);
         //! \brief Get program slot.
         void cmdGetProgram_Click();
         //! \brief Get work dir slot.
