@@ -270,7 +270,6 @@ void IconListWidget::startDrop(QList<QUrl> files){
 }
 
 void IconListWidget::itemClicked (QListWidgetItem *item){
-    return;
     if (!item)
         return;
 
@@ -411,7 +410,7 @@ void IconListWidget::contextMenuEvent (QContextMenuEvent * event){
             QString drive;
             foreach (drive, this->cdromDevices){
                 entry.reset (new QAction(CoreLib->loadIcon("drive-optical"), drive, this));
-                entry->setStatusTip(tr("Mount media drive."));
+                entry->setStatusTip(drive);
                 submenuMount->addAction(entry.release());
             }
         } else {
