@@ -110,20 +110,20 @@ PrefixConfigWidget::PrefixConfigWidget(QWidget *parent) :
     splitter.reset(new QSplitter(this));
     splitter->addWidget(treeFrameWidget.release());
     splitter->addWidget(iconsFrameWidget.release());
+    splitter->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
 
     infoName.reset(new QLabel(QString("%1:\n\%2:").arg(tr("Name")).arg(tr("Description")), this));
-    infoName->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Fixed);
     infoName->setTextInteractionFlags(Qt::TextSelectableByMouse);
     infoName->setWordWrap(true);
     std::auto_ptr<QFrame> frame(new QFrame(this));
 
     layout.reset(new QVBoxLayout(this));
-    layout->setSpacing(0);
+    layout->setSpacing(3);
     layout->setContentsMargins(0,6,0,0);
     layout->addWidget(infoName.get());
 
     frame->setLayout(layout.release());
-    frame->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Fixed);
+    frame->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed);
     infoName->setFrameStyle(QFrame::Raised);
     infoName->setFrameShape(QFrame::StyledPanel);
 
@@ -291,6 +291,10 @@ void PrefixConfigWidget::get_icons(){
                     name = tr("Refresh Winetricks application list");
                     desc = tr("Create or update Q4Wine's cache of Winetricks appications.");
                     iconItem->setIcon(CoreLib->loadIcon("edit-redo"));
+                } else if (items.at(i).name == "%ABOUT_WINETRICKS%"){
+                    name = tr("Goto Winetricks homepage");
+                    desc = tr("Read news, report bugs and join the Winetricks community at https://github.com/Winetricks/winetricks");
+                    iconItem->setIcon(CoreLib->loadIcon("go-home"));
                 }
             }
             iconItem->setText(name);
@@ -412,6 +416,8 @@ void PrefixConfigWidget::itemDoubleClicked (QListWidgetItem *item){
             this->createTree();
         } else if (item->text() == tr("Install or update Winetricks script")){
             wine_t.install_winetricks();
+        } else if (item->text() == tr("Goto Winetricks homepage")){
+            CoreLib->openUrl("https://github.com/Winetricks/winetricks");
         } else {
             wine_t.run_winetricks(item->text());
         }
